==> centreon-web-24.10.13.tar.gz: centreon-web-24.10.13/www/class/centreonUUID.class.php <==
<?php

/*
 * Copyright 2005-2020 Centreon
 * Centreon is developed by : Julien Mathis and Romain Le Merlus under
 * GPL Licence 2.0.
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation ; either version 2 of the License.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
 * PARTICULAR PURPOSE. See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, see <http://www.gnu.org/licenses>.
 *
 * Linking this program statically or dynamically with other modules is making a
 * combined work based on this program. Thus, the terms and conditions of the GNU
 * General Public License cover the whole combination.
 *
 * As a special exception, the copyright holders of this program give Centreon
 * permission to link this program with independent modules to produce an executable,
 * regardless of the license terms of these independent modules, and to copy and
 * distribute the resulting executable under terms of Centreon choice, provided that
 * Centreon also meet, for each linked independent module, the terms  and conditions
 * of the license of that module. An independent module is a module which is not
 * derived from this program. If you modify this program, you may extend this
 * exception to your version of the program, but you are not obliged to do so. If you
 * do not wish to do so, delete this exception statement from your version.
 *
 * For more information : contact@centreon.com
 *
 */

/**
 * Class
 *
 * @class CentreonUUID
 */
class CentreonUUID
{
    /** @var CentreonDB */
    private $db;

    /**
     * CentreonUUID constructor
     *
     * @param CentreonDB $db
     */
    public function __construct($db)
    {
        $this->db = $db;
    }

    /**
     * Get Centreon UUID
     *
     * @return string
     */
    public function getUUID(): string
    {
        if ($uuid = $this->getUUIDFromDatabase()) {
            return $uuid;
        }

        return $this->generateUUID();
    }

    /**
     * Get Centreon UUID previously stored in database
     *
     * @return false|string
     * @throws PDOException
     */
    private function getUUIDFromDatabase(): bool|string
    {
        $query = "SELECT value " .
            "FROM informations " .
            "WHERE informations.key = 'uuid' ";
        $result = $this->db->query($query);

        if ($result !== false && $row = $result->fetch()) {
            /** @var array<string, null|bool|int|string> $row */
            return (string) $row['value'];
        }
        return false;
    }

    /**
     * Generate UUID v4
     *
     * @return string
     * @throws CentreonDbException
     */
    private function generateUUID()
    {
        $uuid = sprintf(
            '%04x%04x-%04x-%04x-%04x-%04x%04x%04x',
            // 32 bits for "time_low"
            mt_rand(0, 0xffff),
            mt_rand(0, 0xffff),
            // 16 bits for "time_mid"
            mt_rand(0, 0xffff),
            // 16 bits for "time_hi_and_version",
            // four most significant bits holds version number 4
            mt_rand(0, 0x0fff) | 0x4000,
            // 16 bits, 8 bits for "clk_seq_hi_res",
            // 8 bits for "clk_seq_low",
            // two most significant bits holds zero and one for variant DCE1.1
            mt_rand(0, 0x3fff) | 0x8000,
            // 48 bits for "node"
            mt_rand(0, 0xffff),
            mt_rand(0, 0xffff),
            mt_rand(0, 0xffff)
        );

        $query = "INSERT INTO informations VALUES ('uuid', ?) ";
        $queryValues = [$uuid];
        $stmt = $this->db->prepare($query);
        $this->db->execute($stmt, $queryValues);

        return $uuid;
    }
}

==> centreon-web-25.10.0.tar.gz: centreon-web-25.10.0/www/class/centreonUUID.class.php <==
<?php

/*
 * Copyright 2005 - 2025 Centreon (https://www.centreon.com/)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * For more information : contact@centreon.com
 *
 */

/**
 * Class
 *
 * @class CentreonUUID
 */
class CentreonUUID
{
    /** @var CentreonDB */
    private $db;

    /**
     * CentreonUUID constructor
     *
     * @param CentreonDB $db
     */
    public function __construct($db)
    {
        $this->db = $db;
    }

    /**
     * Get Centreon UUID
     *
     * @return string
     */
    public function getUUID(): string
    {
        if ($uuid = $this->getUUIDFromDatabase()) {
            return $uuid;
        }

        return $this->generateUUID();
    }

    /**
     * Get Centreon UUID previously stored in database
     *
     * @throws PDOException
     * @return false|string
     */
    private function getUUIDFromDatabase(): bool|string
    {
        $query = 'SELECT value '
            . 'FROM informations '
            . "WHERE informations.key = 'uuid' ";
        $result = $this->db->query($query);

        if ($result !== false && $row = $result->fetch()) {
            /** @var array<string, null|bool|int|string> $row */
            return (string) $row['value'];
        }

        return false;
    }

    /**
     * Generate UUID v4
     *
     * @throws CentreonDbException
     * @return string
     */
    private function generateUUID()
    {
        $uuid = sprintf(
            '%04x%04x-%04x-%04x-%04x-%04x%04x%04x',
            // 32 bits for "time_low"
            mt_rand(0, 0xffff),
            mt_rand(0, 0xffff),
            // 16 bits for "time_mid"
            mt_rand(0, 0xffff),
            // 16 bits for "time_hi_and_version",
            // four most significant bits holds version number 4
            mt_rand(0, 0x0fff) | 0x4000,
            // 16 bits, 8 bits for "clk_seq_hi_res",
            // 8 bits for "clk_seq_low",
            // two most significant bits holds zero and one for variant DCE1.1
            mt_rand(0, 0x3fff) | 0x8000,
            // 48 bits for "node"
            mt_rand(0, 0xffff),
            mt_rand(0, 0xffff),
            mt_rand(0, 0xffff)
        );

        $query = "INSERT INTO informations VALUES ('uuid', ?) ";
        $queryValues = [$uuid];
        $stmt = $this->db->prepare($query);
        $this->db->execute($stmt, $queryValues);

        return $uuid;
    }
}
